@@ -282,16 +282,18 @@ def test_Morphology(ecvl):
         [5, 5, 1], ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR
     )
     tmp = _empty_img(ecvl)
-    ecvl.Morphology(img, tmp, ecvl.MorphTypes.MORPH_BLACKHAT, kernel)
-    ecvl.Morphology(img, tmp, ecvl.MorphTypes.MORPH_BLACKHAT, kernel, [3, 3])
+    ecvl.Morphology(img, tmp, ecvl.MorphType.MORPH_BLACKHAT, kernel)
+    ecvl.Morphology(img, tmp, ecvl.MorphType.MORPH_BLACKHAT, kernel, [3, 3])
     ecvl.Morphology(
-        img, tmp, ecvl.MorphTypes.MORPH_BLACKHAT, kernel, [3, 3], 2
+        img, tmp, ecvl.MorphType.MORPH_BLACKHAT, kernel, [3, 3], 2
     )
     ecvl.Morphology(
-        img, tmp, ecvl.MorphTypes.MORPH_BLACKHAT, kernel, [3, 3], 2, 2
+        img, tmp, ecvl.MorphType.MORPH_BLACKHAT, kernel, [3, 3], 2,
+        ecvl.BorderType.BORDER_REFLECT
     )
     ecvl.Morphology(
-        img, tmp, ecvl.MorphTypes.MORPH_BLACKHAT, kernel, [3, 3], 2, 2, 1
+        img, tmp, ecvl.MorphType.MORPH_BLACKHAT, kernel, [3, 3], 2,
+        ecvl.BorderType.BORDER_REFLECT, 1
     )
 
 
@@ -304,7 +306,7 @@ def test_Inpaint(ecvl):
     )
     tmp = _empty_img(ecvl)
     ecvl.Inpaint(img, tmp, mask, 5.0)
-    ecvl.Inpaint(img, tmp, mask, 5.0, ecvl.InpaintTypes.INPAINT_NS)
+    ecvl.Inpaint(img, tmp, mask, 5.0, ecvl.InpaintType.INPAINT_NS)
 
 
 @pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
@@ -312,3 +314,52 @@ def test_MeanStdDev(ecvl):
     dims = [20, 40, 3]
     img = ecvl.Image(dims, ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR)
     mean, stddev = ecvl.MeanStdDev(img)
+
+
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_Transpose(ecvl):
+    img = ecvl.Image(
+        [20, 40, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR
+    )
+    tmp = _empty_img(ecvl)
+    ecvl.Transpose(img, tmp)
+
+
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_GridDistortion(ecvl):
+    dims = [20, 40, 3]
+    img = ecvl.Image(dims, ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR)
+    tmp = _empty_img(ecvl)
+    ecvl.GridDistortion(img, tmp)
+    ecvl.GridDistortion(img, tmp, 6)
+    ecvl.GridDistortion(img, tmp, 6, [-0.5, 0.5])
+    ecvl.GridDistortion(
+        img, tmp, 6, [-0.5, 0.5], ecvl.InterpolationType.nearest
+    )
+    ecvl.GridDistortion(
+        img, tmp, 6, [-0.5, 0.5], ecvl.InterpolationType.nearest,
+        ecvl.BorderType.BORDER_CONSTANT
+    )
+    ecvl.GridDistortion(
+        img, tmp, 6, [-0.5, 0.5], ecvl.InterpolationType.nearest,
+        ecvl.BorderType.BORDER_CONSTANT, 1
+    )
+
+
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_ElasticTransform(ecvl):
+    dims = [20, 40, 3]
+    img = ecvl.Image(dims, ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR)
+    tmp = _empty_img(ecvl)
+    ecvl.ElasticTransform(img, tmp)
+    ecvl.ElasticTransform(img, tmp, 35)
+    ecvl.ElasticTransform(img, tmp, 35, 5)
+    ecvl.ElasticTransform(img, tmp, 35, 5, ecvl.InterpolationType.nearest)
+    ecvl.ElasticTransform(
+        img, tmp, 35, 5, ecvl.InterpolationType.nearest,
+        ecvl.BorderType.BORDER_CONSTANT
+    )
+    ecvl.ElasticTransform(
+        img, tmp, 35, 5, ecvl.InterpolationType.nearest,
+        ecvl.BorderType.BORDER_CONSTANT, 1
+    )
